wrap_methods

Macro wrap_methods 

wrap_methods!() { /* proc-macro */ }
Wraps a list of methods on an externally-defined type with C-FFI shims. Used by ezffi to expose Rust std struct methods to C.

wrap_methods!(String {
    fn new() -> String;
    fn len(&self) -> usize;
    fn push_str(&mut self, s: &str);
});

Not meant for downstream users (yet). It may be made public in a future release, probably under a different name